@@ -271,7 +271,7 @@ class Checker(runner.Runner):
 
     async def on_check_begin(self, check: str) -> None:
         self._active_check = check
-        self.log.notice(f"[{check}] Running check")
+        self.log.notice(f"[{check}] Running checks...")
 
     async def on_check_run(self, check: str) -> None:
         """Callback hook called after each check run."""
@@ -282,8 +282,12 @@ class Checker(runner.Runner):
             self.log.error(f"[{check}] Check failed")
         elif check in self.warnings:
             self.log.warning(f"[{check}] Check has warnings")
+        elif check not in self.success:
+            self.log.notice(f"[{check}] No checks ran")
         else:
-            self.log.success(f"[{check}] Check completed successfully")
+            self.log.notice(
+                f"[{check}] Checks ({len(self.success[check])}) "
+                "completed successfully")
 
     async def on_checks_begin(self) -> None:
         """Callback hook called before all checks."""
@@ -296,12 +300,11 @@ class Checker(runner.Runner):
             self.summary.print_summary()
         return 1 if self.has_failed else 0
 
-    @runner.cleansup
-    def run(self) -> int:
+    def __call__(self):
         loop = asyncio.get_event_loop()
         loop.set_exception_handler(self.on_async_error)
         try:
-            return loop.run_until_complete(self._run())
+            return loop.run_until_complete(self.run())
         except RuntimeError:
             # Loop was forcibly stopped, most likely due to unhandled
             # error in task.
@@ -488,6 +491,18 @@ class Checker(runner.Runner):
     def preloader_catches(self, task: str) -> Tuple[Type[BaseException], ...]:
         return tuple(self.preload_checks_data[task].get("catches", ()))
 
+    @runner.cleansup
+    async def run(self) -> int:
+        await self.begin_checks()
+        try:
+            await self._run_from_queue()
+        finally:
+            result = (
+                1
+                if self.exiting
+                else await self.on_checks_complete())
+        return result
+
     def _check_should_run(self, check: str) -> bool:
         """Indicate whether a check is ready to run."""
         return bool(
@@ -499,17 +514,6 @@ class Checker(runner.Runner):
                 in self.preload_pending_tasks
                 for task in self.preload_checks[check]))
 
-    async def _run(self) -> int:
-        await self.begin_checks()
-        try:
-            await self._run_from_queue()
-        finally:
-            result = (
-                1
-                if self.exiting
-                else await self.on_checks_complete())
-        return result
-
     async def _run_check(self, check: str) -> None:
         await self.on_check_begin(check)
         await getattr(self, f"check_{check}")()
